<form class="form-{{ type }}" method="{{ method }}"  action="{{ action }}" style='margin: 10px;' >
{% for input in inputs %}
    <div class="form-group"> 
        {% if input[0] == 'checkbox' %}
        <div class="checkbox">
            <label  for="{{ input[1] }}">
                <input name='{{ input[1] }}' style="margin-top: -8px;" type="{{ input[0] }}" class="form-control" id="id-{{ input[1] }}" value="{{ input[2] }}" placeholder="{{  input[1] }}'s value "/>{{ input[1][0].upper() + input[1][1:] }}
                    
            </label>
        </div>
        {% elif input[0] == 'file' %}
            <label for="{{ input[1] }}" style="margin-left: 14px;">
                {{ input[1][0].upper() + input[1][1:]  }}
            </label>
            <input style='margin-left: 25px; width: initial' name='{{ input[1] }}' type="{{ input[0] }}"  id="id-{{ input[1] }}" value="{{ input[2] }}" />
        {% elif input[0] == 'submit' %}
            <button type="submit" class="btn btn-default" >{{ input[2] }}</button>
        {% else %}
            <div class="input-group">
                <div class="input-group-addon">{{ input[0] }}</div>
                    <input name='{{ input[1] }}' type="{{ input[0] }}" class="form-control" id="id-{{ input[1] }}" value="{{ input[2] }}" placeholder="{{  input[1] }}'s value "/>    
                <div class="input-group-addon">{{ input[2] }}</div>
            </div>            
        {% end %}
    </div>
{% end %}
</form >
